pub struct TransferSegment {
pub byte_offset: usize,
pub byte_len: usize,
}Fields
byte_offset: usizeSegment byte offset relative to the containing transfer chunk.
byte_len: usizeTrait Implementations
Sourceimpl Clone for TransferSegment
impl Clone for TransferSegment
Sourcefn clone(&self) -> TransferSegment
fn clone(&self) -> TransferSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TransferSegment
Sourceimpl Debug for TransferSegment
impl Debug for TransferSegment
impl Eq for TransferSegment
Sourceimpl PartialEq for TransferSegment
impl PartialEq for TransferSegment
Sourcefn eq(&self, other: &TransferSegment) -> bool
fn eq(&self, other: &TransferSegment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TransferSegment